@@ -546,120 +546,122 @@ class RtFo(object):
         self.interp = {ii: importlib.import_module("sicor.Tools.NM.interp_spectral_n_%i" % ii) for ii in
                        interpol_dim_range}
         # open LUT hdf5 file and group as defined in table_path
-        self.atm_tables_h5 = tables.open_file(atm_tables_fn, "r")
-        self.atm_tables = self.atm_tables_h5.root
-        self.grp = self.atm_tables.__getattr__(table_path)
-        # copy dimension data names to self, collect in dim_names
-        self.wvl_pca = self.atm_tables.__getattr__(dim_wvl).read()
-        self.wvl = self.wvl_pca
-        self.n_wvl = len(self.wvl_pca)
-        self.dtype = dtype
+        with tables.open_file(atm_tables_fn, "r") as atm_tables_h5:
+            self.atm_tables_h5 = atm_tables_h5
+            self.atm_tables = atm_tables_h5.root
+            self.grp = self.atm_tables.__getattr__(table_path)
+            # copy dimension data names to self, collect in dim_names
+            self.wvl_pca = self.atm_tables.__getattr__(dim_wvl).read()
+            self.wvl = self.wvl_pca
+            self.n_wvl = len(self.wvl_pca)
+            self.dtype = dtype
 
-        self.dim_scat = dim_scat
-        self.dim_atm = dim_atm
-        self.dim_vza = dim_vza
-        self.dim_sza = dim_sza
-        self.dim_azi = dim_azi
-        self.dim_pca = dim_pca
-        self.dim_layer = dim_layer
-        self.dim_names = list(self.dim_atm) + list(self.dim_scat) + [
-            self.dim_vza, self.dim_sza, self.dim_azi, self.dim_pca, self.dim_layer]
+            self.dim_scat = dim_scat
+            self.dim_atm = dim_atm
+            self.dim_vza = dim_vza
+            self.dim_sza = dim_sza
+            self.dim_azi = dim_azi
+            self.dim_pca = dim_pca
+            self.dim_layer = dim_layer
+            self.dim_names = list(self.dim_atm) + list(self.dim_scat) + [
+                self.dim_vza, self.dim_sza, self.dim_azi, self.dim_pca, self.dim_layer]
 
-        self.sza_reduced = None
-        self.vza_reduced = None
+            self.sza_reduced = None
+            self.vza_reduced = None
 
-        # set given slices, default is all elements
-        self.slices = {dim: slice(None) for dim in self.dim_names}
-        for dim, slc in slices.items():
-            self.slices[dim] = slc
-        # same same for hash formats
-        self.hash_formats = {dim: hash_format_default for dim in self.dim_names}
-        for dim, slc in hash_formats.items():
-            self.hash_formats[dim] = slc
-        # set number of principal components, add slice for pca dimension
-        self.n_pca_max = self.grp.E_DN.components.shape[0]
-        self.n_pcs = np.min([self.n_pca_max, n_pcs])
-        self.slices[self.dim_pca] = slice(0, self.n_pcs)
-        # set dictionary for dimension_name:scale
-        self.dims = {dim: np.array(self.atm_tables.__getattr__(dim)[self.slices[dim]], dtype=self.dtype) for dim in
-                     self.dim_names}
-        # convert arccos to degree
-        self.dims[self.dim_vza] = np.rad2deg(np.arccos(self.dims[self.dim_vza]))
-        self.dims[self.dim_sza] = np.rad2deg(np.arccos(self.dims[self.dim_sza]))
+            # set given slices, default is all elements
+            self.slices = {dim: slice(None) for dim in self.dim_names}
+            for dim, slc in slices.items():
+                self.slices[dim] = slc
+            # same same for hash formats
+            self.hash_formats = {dim: hash_format_default for dim in self.dim_names}
+            for dim, slc in hash_formats.items():
+                self.hash_formats[dim] = slc
+            # set number of principal components, add slice for pca dimension
+            self.n_pca_max = self.grp.E_DN.components.shape[0]
+            self.n_pcs = np.min([self.n_pca_max, n_pcs])
+            self.slices[self.dim_pca] = slice(0, self.n_pcs)
+            # set dictionary for dimension_name:scale
+            self.dims = {dim: np.array(self.atm_tables.__getattr__(dim)[self.slices[dim]], dtype=self.dtype) for dim in
+                         self.dim_names}
+            # convert arccos to degree
+            self.dims[self.dim_vza] = np.rad2deg(np.arccos(self.dims[self.dim_vza]))
+            self.dims[self.dim_sza] = np.rad2deg(np.arccos(self.dims[self.dim_sza]))
 
-        # set sensor wavelengths, response function and solar irradiances
-        self.sensors = sensors
-        if self.sensors is not None:
-            self.response_function_threshold = response_function_threshold
-            self.sensor_interpolation_reference = sensor_interpolation_reference
-            self.wvl_sensors = {sensor_name: sensor["wvl_inst"] for sensor_name, sensor in self.sensors.items()}
-            self.sol_irr_sensors = {sensor_name: sensor["sol_irr"] / np.pi for sensor_name, sensor in
-                                    self.sensors.items() if sensor["sol_irr"] is not None}
-            for name, sensor in self.sensors.items():
-                self.__instrument_val__(sensor)
-        self.components = "components"
-        self.mean = "mean"
-        if sol_irr_pca is not None:
-            self.sol_irr_pca = sol_irr_pca / np.pi
-        else:
-            self.sol_irr_pca = None
-        self.sol_irr = self.sol_irr_pca
+            # set sensor wavelengths, response function and solar irradiances
+            self.sensors = sensors
+            if self.sensors is not None:
+                self.response_function_threshold = response_function_threshold
+                self.sensor_interpolation_reference = sensor_interpolation_reference
+                self.wvl_sensors = {sensor_name: sensor["wvl_inst"] for sensor_name, sensor in self.sensors.items()}
+                self.sol_irr_sensors = {sensor_name: sensor["sol_irr"] / np.pi for sensor_name, sensor in
+                                        self.sensors.items() if sensor["sol_irr"] is not None}
+                for name, sensor in self.sensors.items():
+                    self.__instrument_val__(sensor)
+            self.components = "components"
+            self.mean = "mean"
+            if sol_irr_pca is not None:
+                self.sol_irr_pca = sol_irr_pca / np.pi
+            else:
+                self.sol_irr_pca = None
+            self.sol_irr = self.sol_irr_pca
 
-        # each atmospheric function is defined as dictionary with common types as defined in __mk_table__
-        # serves as preparation for the atmospheric dimension interpolation
-        # __mk_table__ creates a spectral subset of the LUT to match the wavelengths (or subset) of the input sensor
-        # process atmospheric path reflection and upward transmittance only at TOA
-        if only_toa:
+            # each atmospheric function is defined as dictionary with common types as defined in __mk_table__
+            # serves as preparation for the atmospheric dimension interpolation
+            # __mk_table__ creates a spectral subset of the LUT to match the wavelengths (or subset) of the input sensor
+            # process atmospheric path reflection and upward transmittance only at TOA
+            if only_toa:
 
-            if buffer_tables is not None and "L0" in buffer_tables:
-                self.L0 = buffer_tables["L0"]
+                if buffer_tables is not None and "L0" in buffer_tables:
+                    self.L0 = buffer_tables["L0"]
+                else:
+                    self.L0 = self.__mk_tble__(
+                        grp=self.grp.L0_TOA,
+                        dims=(list(self.dim_atm) + list(self.dim_scat) +
+                              [self.dim_vza, self.dim_sza, self.dim_azi, self.dim_pca])
+                    )
+
+                if buffer_tables is not None and "T_UP" in buffer_tables:
+                    self.T_UP = buffer_tables["T_UP"]
+                else:
+                    self.T_UP = self.__mk_tble__(
+                        grp=self.grp.T_UP_TOA,
+                        dims=list(self.dim_atm) + list(self.dim_scat) + [self.dim_vza, self.dim_pca],
+                        idx=self.L0["dims"]
+                    )
+            # process atmospheric path reflection and upward transmittance including the layer dimension
             else:
                 self.L0 = self.__mk_tble__(
-                    grp=self.grp.L0_TOA,
+                    grp=self.grp.L0,
                     dims=(list(self.dim_atm) + list(self.dim_scat) +
-                          [self.dim_vza, self.dim_sza, self.dim_azi, self.dim_pca])
+                          [self.dim_layer, self.dim_vza, self.dim_sza, self.dim_azi, self.dim_pca])
                 )
-
-            if buffer_tables is not None and "T_UP" in buffer_tables:
-                self.T_UP = buffer_tables["T_UP"]
-            else:
                 self.T_UP = self.__mk_tble__(
-                    grp=self.grp.T_UP_TOA,
-                    dims=list(self.dim_atm) + list(self.dim_scat) + [self.dim_vza, self.dim_pca],
+                    grp=self.grp.T_UP,
+                    dims=list(self.dim_atm) + list(self.dim_scat) + [self.dim_layer, self.dim_vza, self.dim_pca],
                     idx=self.L0["dims"]
                 )
-        # process atmospheric path reflection and upward transmittance including the layer dimension
-        else:
-            self.L0 = self.__mk_tble__(
-                grp=self.grp.L0,
-                dims=(list(self.dim_atm) + list(self.dim_scat) +
-                      [self.dim_layer, self.dim_vza, self.dim_sza, self.dim_azi, self.dim_pca])
-                                       )
-            self.T_UP = self.__mk_tble__(
-                grp=self.grp.T_UP,
-                dims=list(self.dim_atm) + list(self.dim_scat) + [self.dim_layer, self.dim_vza, self.dim_pca],
-                idx=self.L0["dims"]
-            )
 
-        self.pt_dims = copy(self.L0["dims"])
-        self.pt_dims.remove(self.dim_pca)
-        self.jacobean_switch = {dim_name: 1 for dim_name in self.pt_dims}
+            self.pt_dims = copy(self.L0["dims"])
+            self.pt_dims.remove(self.dim_pca)
+            self.jacobean_switch = {dim_name: 1 for dim_name in self.pt_dims}
 
-        if buffer_tables is not None and "E_DN" in buffer_tables:
-            self.E_DN = buffer_tables["E_DN"]
-        else:
-            self.E_DN = self.__mk_tble__(grp=self.grp.E_DN,
-                                         dims=list(self.dim_atm) + list(self.dim_scat) + [self.dim_sza, self.dim_pca],
-                                         idx=self.L0["dims"]
-                                         )
+            if buffer_tables is not None and "E_DN" in buffer_tables:
+                self.E_DN = buffer_tables["E_DN"]
+            else:
+                self.E_DN = self.__mk_tble__(grp=self.grp.E_DN,
+                                             dims=list(self.dim_atm) + list(self.dim_scat) + [self.dim_sza,
+                                                                                              self.dim_pca],
+                                             idx=self.L0["dims"]
+                                             )
 
-        if buffer_tables is not None and "SS" in buffer_tables:
-            self.SS = buffer_tables["SS"]
-        else:
-            self.SS = self.__mk_tble__(grp=self.grp.SS,
-                                       dims=list(self.dim_atm) + list(self.dim_scat) + [self.dim_pca],
-                                       idx=self.L0["dims"]
-                                       )
+            if buffer_tables is not None and "SS" in buffer_tables:
+                self.SS = buffer_tables["SS"]
+            else:
+                self.SS = self.__mk_tble__(grp=self.grp.SS,
+                                           dims=list(self.dim_atm) + list(self.dim_scat) + [self.dim_pca],
+                                           idx=self.L0["dims"]
+                                           )
 
         # settings for interpolation between atmospheric dimensions
         self.__jacobean__ = False
