@@ -699,17 +699,16 @@ class ECMWF_variable(object):
         if delta_day != 0:
             self.logger.warning("ECMWF data of a different date than the acquisition day are used.")
 
-        h5f = h5py.File(name=self.fn, mode="r")
-        if 'steps' not in h5f.keys():
-            self.steps = np.array([0], dtype=dtype)
-        else:
-            self.steps = np.array(h5f["steps"][()][:], dtype=dtype)
-        self.lat = np.array(h5f["lat"][()][:], dtype=dtype)
-        self.lon = np.array(h5f["lon"][()][:], dtype=dtype)
-        self.variable = np.array(h5f[variable][()][:, :, :], dtype=dtype)
-        self.var = RegularGridInterpolator(points=(self.steps, self.lat[::-1], self.lon),
-                                           values=self.variable[:, ::-1, :], method="linear")
-        h5f.close()
+        with h5py.File(name=self.fn, mode="r") as h5f:
+            if 'steps' not in h5f.keys():
+                self.steps = np.array([0], dtype=dtype)
+            else:
+                self.steps = np.array(h5f["steps"][()][:], dtype=dtype)
+            self.lat = np.array(h5f["lat"][()][:], dtype=dtype)
+            self.lon = np.array(h5f["lon"][()][:], dtype=dtype)
+            self.variable = np.array(h5f[variable][()][:, :, :], dtype=dtype)
+            self.var = RegularGridInterpolator(points=(self.steps, self.lat[::-1], self.lon),
+                                               values=self.variable[:, ::-1, :], method="linear")
 
     def __call__(self, step, lons, lats, shape=None, order=3, dtype=np.float32, force_bounds=True):
         """
