@@ -218,48 +218,46 @@ def dict_conv(inp):
 
 
 def write_classical_bayesian_to_hdf5_file(clf, filename, class_names, mask_legend, clf_to_col, band_names):
-    h5f = h5py.File(filename, 'w')
-    for name, data in [("class_names", class_names),
-                       ("mask_legend", mask_legend),
-                       ("classifiers_fk", clf.mk_clf.classifiers_fk),
-                       ("classifiers_id", clf.mk_clf.classifiers_id),
-                       ("n_bins", clf.n_bins),
-                       ("n_classes", clf.n_classes),
-                       ("clf_to_col", clf_to_col),
-                       ("band_names", band_names),
-                       ]:
-        h5f.create_dataset(name, data=json.dumps(data))
-    h5f.create_dataset("classes", data=clf.classes)
+    with h5py.File(filename, 'w') as h5f:
+        for name, data in [("class_names", class_names),
+                           ("mask_legend", mask_legend),
+                           ("classifiers_fk", clf.mk_clf.classifiers_fk),
+                           ("classifiers_id", clf.mk_clf.classifiers_id),
+                           ("n_bins", clf.n_bins),
+                           ("n_classes", clf.n_classes),
+                           ("clf_to_col", clf_to_col),
+                           ("band_names", band_names),
+                           ]:
+            h5f.create_dataset(name, data=json.dumps(data))
+        h5f.create_dataset("classes", data=clf.classes)
 
-    keys, values = dict_conv(clf.hh_n)
-    h5f.create_dataset("hh_n_keys", data=keys)
-    h5f.create_dataset("hh_n_values", data=values)
+        keys, values = dict_conv(clf.hh_n)
+        h5f.create_dataset("hh_n_keys", data=keys)
+        h5f.create_dataset("hh_n_values", data=values)
 
-    h5f.create_dataset("hh_full", data=clf.hh_full, compression="lzf")
+        h5f.create_dataset("hh_full", data=clf.hh_full, compression="lzf")
 
-    bns_names = []
-    for ii, bn in enumerate(clf.bns):
-        name = "bns_%i" % ii
-        bns_names.append(name)
-        h5f.create_dataset(name, data=bn)
-    h5f.create_dataset("bns_names", data=json.dumps(bns_names))
+        bns_names = []
+        for ii, bn in enumerate(clf.bns):
+            name = "bns_%i" % ii
+            bns_names.append(name)
+            h5f.create_dataset(name, data=bn)
+        h5f.create_dataset("bns_names", data=json.dumps(bns_names))
 
-    bb_full_names = []
-    for ii, bn in enumerate(clf.bb_full):
-        name = "bb_full_%i" % ii
-        bb_full_names.append(name)
-        h5f.create_dataset(name, data=bn)
-    h5f.create_dataset("bb_full_names", data=json.dumps(bb_full_names))
+        bb_full_names = []
+        for ii, bn in enumerate(clf.bb_full):
+            name = "bb_full_%i" % ii
+            bb_full_names.append(name)
+            h5f.create_dataset(name, data=bn)
+        h5f.create_dataset("bb_full_names", data=json.dumps(bb_full_names))
 
-    names = []
-    for key, value in clf.hh.items():
-        name = "hh_%i" % key
-        names.append(name)
-        h5f.create_dataset("%s_key" % name, data=key)
-        h5f.create_dataset("%s_value" % name, data=value, compression="lzf")
-    h5f.create_dataset("hh_names", data=json.dumps(names))
-
-    h5f.close()
+        names = []
+        for key, value in clf.hh.items():
+            name = "hh_%i" % key
+            names.append(name)
+            h5f.create_dataset("%s_key" % name, data=key)
+            h5f.create_dataset("%s_value" % name, data=value, compression="lzf")
+        h5f.create_dataset("hh_names", data=json.dumps(names))
 
 
 def __test__(clf, xx, yy, sample_weight=None, norm="right_class"):
