@@ -56,8 +56,9 @@ class GranuleDEM(object):
             self.get_dem = None
             self.get_dem = self._get_dem_hdf5
             try:
-                self.h5f = h5py.File(name=self.fn, mode="r")
-                self.tiles = sorted(list(self.h5f.keys()))
+                with h5py.File(name=self.fn, mode="r") as h5f:
+                    self.h5f = h5f
+                    self.tiles = sorted(list(self.h5f.keys()))
             except OSError:
                 self.logger.warning("File:%s missing -> proceed for now." % self.fn)
                 self.h5f = None
