@@ -585,7 +585,15 @@ def ac_interpolation(iband, band, s2img, s2spr, s2cwv, s2tau, clear_areas, point
 
                     r_min, r_max = np.max(rhos[rhos < r_min]), np.min(rhos[rhos > r_max])
                     sel = np.logical_and(r_min <= rhos, rhos <= r_max)
-                    res = griddata(points=points[sel, :], values=rhos[sel], xi=xi)
+                    points_sel = points[sel, :]
+                    values_sel = rhos[sel]
+                    for ii in range(points_sel.shape[0]):
+                        index = points_sel.shape[0] - ii
+                        try:
+                            res = griddata(points=points_sel[:index, :], values=values_sel[:index], xi=xi)
+                            break
+                        except RuntimeError:
+                            pass
                 except (ValueError, IndexError):
                     res = griddata(points=points, values=rhos, xi=xi)  # old version
 
@@ -704,7 +712,7 @@ class IO(object):
                              nodata_value_data=opts["nodata_value_data"],
                              nodata_value_mask=opts["nodata_value_mask"],
                              driver=opts["gdal_driver"],
-                             options_loseless=opts["options_loseless"],
+                             options_lossless=opts["options_lossless"],
                              options_lossy=opts["options_lossy"],
                              options_mask=opts["options_mask"],
                              n_cores=opts["n_cores"],
@@ -763,7 +771,7 @@ class IO(object):
     @staticmethod
     def write_l2a(granule_path, band_fns, projection, data=None, uncert=None, msk=None, driver="JP2OpenJPEG",
                   logger=None,
-                  options_loseless={"JP2OpenJPEG": ["QUALITY=100", "REVERSIBLE=YES"]}, clear_areas=None,
+                  options_lossless={"JP2OpenJPEG": ["QUALITY=100", "REVERSIBLE=YES"]}, clear_areas=None,
                   options_lossy={"JP2OpenJPEG": ["QUALITY=30", "REVERSIBLE=NO"]},
                   options_mask={"JP2OpenJPEG": ["QUALITY=100", "REVERSIBLE=YES", "WRITE_METADATA=YES"]},
                   n_cores=3, max_time_minutes=20, mask_ss=[10.0, 20.0, 60.0], mask_geo_band="B11",
@@ -806,7 +814,7 @@ class IO(object):
                 "projection": projection[band]["prj"],
                 "geotransform": projection[band]["gt"],
                 "logger": None if n_cores != 1 else logger,
-                "options": options_loseless[driver],
+                "options": options_lossless[driver],
                 "metadata": {"scaling_value": 10000},
                 "fmt_funktion": conv(scale=10000, dtype=np.uint16)} for ss, bands in output_bands.items() for band in
                 bands if band in data]
@@ -915,7 +923,7 @@ class IO(object):
                 "projection": projection[mask_geo_band]["prj"],
                 "geotransform": projection[mask_geo_band]["gt"],
                 "logger": None if n_cores != 1 else logger,
-                "options": options_loseless[driver],
+                "options": options_lossless[driver],
                 "metadata": {"scaling_value": 1000, "name": "aerosol optical thickness at 550nm", "unit": 1},
                 "fmt_funktion": conv(scale=1000, dtype=np.uint16)} for ss in ss_other]
 
@@ -933,7 +941,7 @@ class IO(object):
                 "projection": projection[mask_geo_band]["prj"],
                 "geotransform": projection[mask_geo_band]["gt"],
                 "logger": None if n_cores != 1 else logger,
-                "options": options_loseless[driver],
+                "options": options_lossless[driver],
                 "metadata": {"scaling_value": 100, "name": "columnar water vapour", "unit": "mm"},
                 "fmt_funktion": conv(scale=100, dtype=np.uint16)} for ss in ss_other]
 
