@@ -17,6 +17,7 @@ import shutil
 import re
 import platform
 import warnings
+import gdown
 
 from datetime import date
 from io import StringIO
@@ -136,7 +137,7 @@ def coreg_s2(granule="", ref_image_fn=None, ref_image_basepath=None, window_size
         stream = None
 
     options = get_options(target=settings)
-    option_loseless = options["output"][0]["options_loseless"][fmt_out]
+    option_loseless = options["output"][0]["options_lossless"][fmt_out]
 
     try:  # -> e.g. "33UUU"
         tile = re.search('_T[0-9]{2,2}[A-Z]{3,3}_', granule).group(0).replace("_", "")[1:]
@@ -265,7 +266,7 @@ def coreg_s2(granule="", ref_image_fn=None, ref_image_basepath=None, window_size
         dt = date.today()
         logfn = path.join(logdir, str(dt.year), str(dt.month), str(dt.day),
                           "processing_status_%s" % status.status, tile,
-                          basename(os.path.normpath(granule)) + ".json")
+                          basename(path.normpath(granule)) + ".json")
         logger.info("Write logs to: %s" % logfn)
         logdict = {
             "interface": (lambda ii: {nn: ii.locals[nn] for nn in ii.args if nn not in ["logger"]})(
@@ -331,8 +332,8 @@ def check_if_processed(orig_image_fn, cor_image_fn, threshold=0.2):
     if in the range of +-10% of the original image, continue, otherwise delete corrected image
     """
     if path.exists(cor_image_fn):
-        size_orig = float(os.path.getsize(orig_image_fn))
-        size_cor = float(os.path.getsize(cor_image_fn))
+        size_orig = float(path.getsize(orig_image_fn))
+        size_cor = float(path.getsize(cor_image_fn))
         if ((size_orig - size_orig * threshold) < size_cor) & ((size_orig + size_orig * threshold) > size_cor):
             return True, {""}
         else:
@@ -710,10 +711,81 @@ def ac_gms(s2img, options, logger=None, script=True):
     sensor_ac = "%s_AC" % sensor
     sensor_aot = "%s_AOT" % sensor
 
-    # downloading cloud mask, novelty detector, and AC LUT from Google Drive
-    logger.info("If not already available, download needed AC tables from Google Drive.")
-    from sicor.tables import get_tables
-    get_tables(sensor="s2")
+    # check if AC tables are available
+    logger.info("Check if AC tables are available.")
+    from . import tables
+    sicor_table_path = path.dirname(tables.__file__)
+    for scat_type, op in options["RTFO"].items():
+        default_table_path = path.join(sicor_table_path, op['atm_tables_fn'])
+        if path.isfile(op['atm_tables_fn']):
+            logger.info("AC table for scattering type %s is available at user-provided path, proceed." % scat_type)
+        elif path.isfile(default_table_path):
+            logger.info("No valid path to AC table for scattering type %s is provided by the user." % scat_type)
+            logger.info("Instead, AC table for scattering type %s is available at default tables path, "
+                        "proceed." % scat_type)
+            op['atm_tables_fn'] = default_table_path
+        else:
+            logger.info("AC table for scattering type %s is neither available at user-provided path "
+                        "nor in default tables path." % scat_type)
+            logger.info("Download AC table for scattering type %s from google drive "
+                        "and store at default tables path." % scat_type)
+            url = 'https://drive.google.com/uc?export=download&id=1-__e8dMlJMC_Lbt5q9-LwS-L5wghKYnn'
+            gdown.download(url, default_table_path, quiet=False)
+            # check if AC table was properly downloaded
+            try:
+                assert os.path.getsize(default_table_path) == op["atm_tables_size"]
+                logger.info("AC table for scattering type %s was properly downloaded "
+                            "and is available for AC!" % scat_type)
+            except AssertionError:
+                raise AssertionError("AC table for scattering type %s was not properly downloaded. "
+                                     "Please restart AC and try again." % scat_type)
+            op['atm_tables_fn'] = default_table_path
+
+    # check if cloud mask persistence file is available
+    logger.info("Check if cloud mask persistence file is available.")
+    default_cld_msk_path = path.join(sicor_table_path, options["cld_mask"]["persistence_file"])
+    if path.isfile(options["cld_mask"]["persistence_file"]):
+        logger.info("Cloud mask persistence file is available at user-provided path, proceed.")
+    elif path.isfile(default_cld_msk_path):
+        logger.info("No valid path to cloud mask persistence file is provided by the user.")
+        logger.info("Instead, cloud mask persistence file is available at default tables path, proceed.")
+        options["cld_mask"]["persistence_file"] = default_cld_msk_path
+    else:
+        logger.info("Cloud mask persistence file is neither available at user-provided path "
+                    "nor in default tables path.")
+        logger.info("Download cloud mask persistence file from google drive and store at default tables path.")
+        url = 'https://drive.google.com/uc?export=download&id=1PHmX24B_LkbGRgfntQbYc8NWlSkdIX-M'
+        gdown.download(url, default_cld_msk_path, quiet=False)
+        # check if cloud mask persistence file was properly downloaded
+        try:
+            assert os.path.getsize(default_cld_msk_path) == options["cld_mask"]["persistence_file_size"]
+            logger.info("Cloud mask persistence file was properly downloaded and is available for AC!")
+        except AssertionError:
+            raise AssertionError("Cloud mask persistence file was not properly downloaded. "
+                                 "Please restart AC and try again.")
+        options["cld_mask"]["persistence_file"] = default_cld_msk_path
+
+    # check if novelty detector is available
+    logger.info("Check if novelty detector is available.")
+    default_nov_det_path = path.join(sicor_table_path, options["cld_mask"]["novelty_detector"])
+    if path.isfile(options["cld_mask"]["novelty_detector"]):
+        logger.info("Novelty detector is available at user-provided path, proceed.")
+    elif path.isfile(default_nov_det_path):
+        logger.info("No valid path to novelty detector is provided by the user.")
+        logger.info("Instead, novelty detector is available at default tables path, proceed.")
+        options["cld_mask"]["novelty_detector"] = default_nov_det_path
+    else:
+        logger.info("Novelty detector is neither available at user-provided path nor in default tables path.")
+        logger.info("Download novelty detector from google drive and store at default tables path.")
+        url = 'https://drive.google.com/uc?export=download&id=1k0m5fJCBiJbVAoPQPfN0iqn3LnI3UVvu'
+        gdown.download(url, default_nov_det_path, quiet=False)
+        # check if novelty detector was properly downloaded
+        try:
+            assert os.path.getsize(default_nov_det_path) == options["cld_mask"]["novelty_detector_size"]
+            logger.info("Novelty detector was properly downloaded and is available for AC!")
+        except AssertionError:
+            raise AssertionError("Novelty detector was not properly downloaded. Please restart AC and try again.")
+        options["cld_mask"]["novelty_detector"] = default_nov_det_path
 
     # preprocessing => derive cloud mask
     # if input image provides no cloud mask, derive own mask from cld_mask persistence file
@@ -1120,10 +1192,14 @@ def ac_gms(s2img, options, logger=None, script=True):
             band: sol_irr * s2img.metadata["U"] * np.cos(np.deg2rad(s2img.metadata['sun_mean_zenith'])) / np.pi for
             band, sol_irr in s2img.metadata['solar_irradiance'].items()}
 
-        if path.isfile(str(options["uncertainties"]["snr_model"])):
-            s2snr = s2_snr_model(s2_snr_csv_file=options["uncertainties"]["snr_model"], rfl_to_rad=rfl_to_rad)
-        elif isinstance(options["uncertainties"]["snr_model"], Number):
+        from .sensors import S2MSI
+        sicor_s2_uncertainties_path = path.dirname(S2MSI.__file__)
+        if isinstance(options["uncertainties"]["snr_model"], Number):
             s2snr = const_snr_model(options["uncertainties"]["snr_model"])
+        elif path.isfile(path.join(sicor_s2_uncertainties_path, "data", options["uncertainties"]["snr_model"])):
+            options["uncertainties"]["snr_model"] = path.join(sicor_s2_uncertainties_path, "data",
+                                                              options["uncertainties"]["snr_model"])
+            s2snr = s2_snr_model(s2_snr_csv_file=options["uncertainties"]["snr_model"], rfl_to_rad=rfl_to_rad)
         else:
             raise ValueError('options["uncertainties"]["snr_model"] = {val} is not understood.'.format(
                 val=str(options["uncertainties"]["snr_model"])))
