@@ -11,8 +11,6 @@ import pickle
 import gzip
 from sicor.Tools import SolarIrradiance
 from tqdm import tqdm
-from scipy.interpolate import griddata
-from sklearn.decomposition import PCA
 from itertools import product
 from typing import Sequence
 
@@ -511,6 +509,8 @@ def optimize_inverse_table(enmap_l1b: EnMAPL1Product_SensorGeo, fo, options: dic
         is None is given, no PCA is performed
     :return: Numpy array with results for detector and dim_red
     """
+    from scipy.interpolate import griddata  # import here to avoid static TLS ImportError
+
     logger = logger or logging.getLogger(__name__)
     detector = getattr(enmap_l1b, detector_name)
     meta = getattr(enmap_l1b.meta, detector_name)
@@ -606,6 +606,8 @@ def optimize_inverse_table(enmap_l1b: EnMAPL1Product_SensorGeo, fo, options: dic
             values = np.stack(values)  # corresponding values for dim_opt
 
             if n_pca is not None:
+                from sklearn.decomposition import PCA  # import here to avoid static TLS ImportError
+
                 pc = PCA(n_components=n_pca).fit(detector.data[col_sel, icol, :][:, wvl_sel])
                 rr = griddata(
                     pc.transform(points),
